@@ -1,9 +1,11 @@
 from .display_metrics_callback import DisplayMetricsCallback
 from .lr_logger import LrLogger
 from .nil_callback import NilCallback
+from .earlystop_lr import EarlyStoppingLR
 
 __all__ = [
     "LrLogger",
     "NilCallback",
-    "DisplayMetricsCallback"
+    "DisplayMetricsCallback",
+    "EarlyStoppingLR",
 ]
